@@ -22,7 +22,7 @@ access to all that module's methods.
 
 Other methods include:
 
-    $name = $nameserver->name;
+    $name = $domain->name;
 
 Returns a L<Net::DNS::Domain> representing the name of the nameserver.
 
@@ -30,6 +30,16 @@ Returns a L<Net::DNS::Domain> representing the name of the nameserver.
 
 sub name { Net::DNS::Domain->new($_[0]->{'ldhName'}) }
 
+=pod
+
+    $name = $domain->unicodeName;
+
+Returns a string containing the DNS Unicode name of the domain (or C<undef>).
+
+=cut
+
+sub unicodeName { $_[0]->{'unicodeName'} }
+
 =pod
 
     @ns = $domain->nameservers;
@@ -134,6 +144,17 @@ corresponding to the domain.
 
 sub network { Net::RDAP::Obect::IPNetwork->new($_[0]->{'network'}) }
 
+=pod
+
+    my @variants = $domain->variants;
+
+Returns a (potentially empty) array of L<Net::RDAP::Variant> objects
+representing variants of the domain name.
+
+=cut
+
+sub variants { $_[0]->objects('Net::RDAP::Variant', $_[0]->{'variants'}) }
+
 =pod
 
 =head1 COPYRIGHT
